@@ -12,9 +12,10 @@ import paho.mqtt.client as mqtt
 import paho.mqtt.publish as publish
 import pandas as pd
 import urllib3
+import logging
+from io_connect.utilities.store import Logger
 
 import io_connect.constants as c
-import io_connect.utilities.logger as logger
 
 # Disable pandas' warning about chained assignment
 pd.options.mode.chained_assignment = None
@@ -25,12 +26,19 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 @typechecked
 class MQTTHandler:
-    __version__ = "0.1.0"
+    __version__ = c.VERSION
     """Class for managing MQTT communication,
     including publishing data to an MQTT broker
     and handling message processing and client connections."""
 
-    def __init__(self, username: str, password: str, host: str, port: int):
+    def __init__(
+        self,
+        username: str,
+        password: str,
+        host: str,
+        port: int,
+        logger: Optional[logging.Logger] = None,
+    ):
         self.username = username
         self.password = password
         self.host = host
@@ -38,6 +46,7 @@ class MQTTHandler:
         self.auth = {"username": self.username, "password": self.password}
         self.topics = None
         self.func = None
+        self.logger = Logger(logger)
 
     def __validate(self, messages: list):
         """
@@ -110,8 +119,8 @@ class MQTTHandler:
             # Iterate over the messages in chunks and publish each chunk
             for i in range(0, total_messages, chunk_size):
                 # Log the progress of chunk publishing
-                logger.display_log(
-                    f"[INFO] Publishing chunk: {int(i/chunk_size)} of {total_chunks}."
+                self.logger.display_log(
+                    f"[INFO] Publishing chunk: {int(i / chunk_size)} of {total_chunks}."
                 )
 
                 # Get the current chunk of messages to be published
@@ -129,7 +138,7 @@ class MQTTHandler:
                 time.sleep(c.SLEEP_TIME)
 
             # Log success message after all chunks are published
-            logger.display_log("[INFO] Data Published Successfully!")
+            self.logger.display_log("[INFO] Data Published Successfully!")
 
         # Handle ValueError if chunk size is invalid or any message is missing 'topic' or 'payload'
         except ValueError as e:
@@ -176,7 +185,7 @@ class MQTTHandler:
             # Iterate over each message and publish it
             for index, message in enumerate(messages):
                 # Log the progress of message publishing
-                logger.display_log(
+                self.logger.display_log(
                     f"[INFO] Publishing message: {index} of {total_messages}."
                 )
 
@@ -190,7 +199,7 @@ class MQTTHandler:
                 )
 
             # Log success message after all messages are published
-            logger.display_log("[INFO] Data Published Successfully!")
+            self.logger.display_log("[INFO] Data Published Successfully!")
 
         # Handle ValueError if any message is missing 'topic' or 'payload'
         except ValueError as e:
@@ -372,16 +381,11 @@ class MQTTHandler:
             Exception: For other errors that may occur during payload generation.
         """
         try:
-            required_columns = ["device", "topic", "unixtime"]
-
-            missing_columns = set(required_columns) - set(df.columns)
-
             # Check if all required columns are present in the DataFrame
-            if missing_columns:
+            required_columns = {"device", "topic", "unixtime"}
+            if not required_columns.issubset(df.columns):
                 raise ValueError(
-                    "DataFrame is missing one or more required columns: {}".format(
-                        missing_columns
-                    )
+                    f"DataFrame must contain the following columns: {required_columns}"
                 )
 
             if not tag_columns:
@@ -592,7 +596,7 @@ class MQTTHandler:
 
         try:
             decoded_msg = message.payload.decode("utf-8")
-            threading.Thread(target=lambda: self.func(decoded_msg)).start()
+            threading.Thread(target=lambda: self.func(client, decoded_msg)).start()
 
         # Handle any exceptions that may occur
         except Exception as e:
